@@ -637,16 +637,15 @@ class _Session(object):
         resp = []
         syntax_error = False
         while 1:
-            line = self.expect(['\n', '\A[\w ]*>'])
-            if line.rstrip() == '\x03':
+            line = self.expect(['\n', '\A[\w]+>>? '])
+            if line.rstrip().endswith('\x03'):
                 break
-            elif line.rstrip() == '\x15':
+            elif line.rstrip().endswith('\x15'):
                 msg = ('Oct2Py tried to run:\n"""\n{0}\n"""\n'
                        'Octave returned:\n{1}'
                        .format(main_line, '\n'.join(resp)))
                 raise Oct2PyError(msg)
-            elif line.endswith('>') and not syntax_error:
-                line += self.expect(' ')
+            elif not line.endswith('\n') and not syntax_error:
                 self.interact(line)
                 self.write('clear _\n')
                 resp = resp[:-4]
@@ -752,7 +751,10 @@ class _Session(object):
         self.stdout.write(msg)
         while 1:
             inp_func = input if not PY2 else raw_input
-            inp = inp_func() + '\n'
+            try:
+                inp = inp_func() + '\n'
+            except EOFError:
+                return
             if inp in ['exit\n', 'quit\n', 'dbcont\n', 'dbquit\n']:
                 inp = 'return\n'
             self.write('disp(char(3));' + inp)
